.. _utility_functions:
.. currentmodule:: climt

General Utilities
==================
This documents some utility functions available in :mod:`climt`.
Most of the constants functionality is inherited from :mod:`sympl`.

Constants
----------

.. autosummary::
    :toctree: generated/

    get_constant
    set_constant
    reset_constants
    list_available_constants
    set_constants_from_dict

Miscellaneous
--------------

.. autosummary::
    :toctree: generated/

    mass_to_volume_mixing_ratio
    get_interface_values


